Node

Struct Node 

pub struct Node {
    pub node_type: NodeType,
    pub is_root: bool,
    pub parent_offset: Option<Offset>,
}
Node represents a node in the BTree occupied by a single page in memory.

Fields

node_type: NodeTypeis_root: boolparent_offset: Option<Offset>

Implementations

Source

impl Node

pub fn new( node_type: NodeType, is_root: bool, parent_offset: Option<Offset>, ) -> Node

pub fn split(&mut self, b: usize) -> Result<(Key, Node), Error>

split creates a sibling node from a given node by splitting the node in two around a median. split will split the child at b leaving the [0, b-1] keys while moving the set of [b, 2b-1] keys to the sibling.